@@ -32,7 +32,7 @@
 #include <Lum/Edit/Text.h>
 
 #include <Lum/Model/Action.h>
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 
 #include <Lum/OS/Bitmap.h>
 #include <Lum/OS/Font.h>
@@ -64,6 +64,9 @@ namespace Lum {
 
     public:
       void SetArea(size_t x1, size_t x2, const Style& style);
+      void SetBackground(size_t x1, size_t x2,
+                         const Style& normalStyle,
+                         const Style& backgroundStyle);
       void SetDecoration(size_t x1, unsigned long decoration);
     };
 
@@ -83,6 +86,7 @@ namespace Lum {
       bool         showTab;
       bool         highlightTab;
       bool         showSpace;
+      bool         showCurrentLine;
       FunctionMap  keys;
       Syntax       *syntax;
 
@@ -113,6 +117,9 @@ namespace Lum {
       bool ShowSpace() const;
       void SetShowSpace(bool show);
 
+      bool ShowCurrentLine() const;
+      void SetShowCurrentLine(bool show);
+
       Function GetFunctionForKey(const std::wstring& key) const;
       bool RegisterKey(const std::wstring& name, Function function);
 
@@ -145,35 +152,23 @@ namespace Lum {
 
       // Prefs
       size_t                  hScrollOffset;
-      bool                    showCurrentLine;
+      bool                    requiresKnob;
 
       // low level text display stuff
-      size_t                  horizOffset;
       size_t                  spaceWidth;
       Cursor                  *startLine;
       Cursor                  *workCursor;
 
-      // visual controls
-      Model::SizeTRef         top;
-      Model::SizeTRef         first;
-
       OS::FontRef             font;
       OS::Bitmap              *drawBuffer;
 
       std::vector<Line>       lines;
 
-      // Move region
-      bool                    moveRegion;
-      size_t                  mrCount;
-      size_t                  mrStart;
-      size_t                  mrEnd;
-
-      // Move cursor
-      bool                    moveCursor;
-      size_t                  cox;
-      size_t                  coy;
-      size_t                  cnx;
-      size_t                  cny;
+      // refresh tracking
+      std::list<size_t>       refreshLines;   //! List of lines (line in model) that needs refreshing
+      bool                    refreshMove;    //! Refresh will just move text, without redrawing individual lines
+      size_t                  refreshLastTop; //! top position of last draw
+      bool                    refreshFull;    //! Refresh will be a complete resync and redraw
 
       Model::ActionRef        actionPropertyChanged;
       Model::ActionRef        actionFunctionExecuted;
@@ -203,6 +198,10 @@ namespace Lum {
       bool                    showBlockCursor;
 
     private:
+      // RefreshTracking
+      bool CanRefreshRedraw() const;
+      bool CanRefreshMove() const;
+    
       void ResizeLines();
 
       void GetLine(size_t y, Cursor* &cursor) const;
@@ -211,29 +210,22 @@ namespace Lum {
 
       bool CoordsToTextPos(int cX, int cY, size_t &x, size_t &y);
 
-      void SetDirtyVisibleRange(size_t a, size_t b);
-      void SetDirtyRange(size_t y1, size_t y2);
-      void SetDirtyLine(size_t y);
+      void SetDirtyVisibleRange(size_t start, size_t size);
+      void SetDirty(size_t line);
 
-      void MoveRegion(size_t start, size_t end, long count);
       void MoveCursor(size_t ox, size_t oy, size_t nx, size_t ny);
 
       void PrintChar(OS::DrawInfo* draw,
                      LineInfo& info,
                      size_t pos, size_t x);
-      void PrintLine(OS::DrawInfo* draw, LineInfo& info, size_t pos);
+      void PrintLine(OS::DrawInfo* draw, LineInfo& info,
+                     size_t pos, size_t line);
 
-      void Update();
+      void Update(OS::DrawInfo* draw);
       void UpdateDimensions();
-      void UpdateDelete(size_t from, size_t count);
-      void UpdateInsert(size_t from, size_t count);
 
       void ClearSelectionInternal();
 
-      void HandleResize(size_t height);
-
-      void SupplyDoubleBufferBitmap();
-
     public:
       Edit();
       ~Edit();
@@ -252,6 +244,9 @@ namespace Lum {
 
       void DisplayBeep();
 
+      void SetRequiresKnobs(bool requiresKnob);
+
+      bool RequiresKnobs() const;
       bool IsWriteable() const;
 
       bool IsVisible(size_t y) const;
@@ -295,12 +290,13 @@ namespace Lum {
       void ShowBlock();
       void HideBlock();
 
-      void SetDirtyAll(); // Will be made private
-
       bool SetModel(Base::Model* model);
 
       void CalcSize();
-      void Draw(int x, int y, size_t w, size_t h);
+      void GetDimension(size_t& width, size_t& height);
+      void Layout();
+      void Draw(OS::DrawInfo* draw,
+                int x, int y, size_t w, size_t h);
 
       void DrawFocus();
       void HideFocus();
