@@ -40,16 +40,15 @@
 #include <Lum/OS/Image.h>
 
 namespace Lum {
+  namespace Manager {
+    class Keyboard;
+  }
+
   namespace OS {
 
-    class Behaviour; // The display holds a concrete behaviour, but does not know anything about them
     class Theme;     // The display holds a concrete behaviour, but does not know anything about them
     class Window;    // Forward declaration to avoid recursive includes
 
-    namespace Manager {
-      class KeyboardManager;
-    }
-
     /**
       Display represents the graphical display with all its global attributes.
     */
@@ -487,10 +486,6 @@ namespace Lum {
       virtual void SetAppName(const std::wstring& name) = 0;
       virtual std::wstring GetAppName() const = 0;
 
-      virtual void SetArgs(const std::vector<std::wstring>& args) = 0;
-      virtual size_t GetArgCount() const = 0;
-      virtual std::wstring GetArg(size_t pos) const = 0;
-
       /**
         @name Theming
         Methods for dealing with themes.
@@ -501,14 +496,6 @@ namespace Lum {
       virtual Theme* GetTheme() const = 0;
       //@}
 
-      /**
-        @name Behaviour
-        Methods for dealing with configurable behaviour.
-      */
-      //@{
-      virtual Behaviour* GetBehaviour() const = 0;
-      //@}
-
       virtual size_t GetSpaceHorizontal(Space space) const = 0;
       virtual size_t GetSpaceVertical(Space space) const = 0;
 
@@ -527,7 +514,7 @@ namespace Lum {
         input methods.
       */
       //@{
-      virtual Manager::KeyboardManager* GetKeyboardManager() const = 0;
+      virtual Manager::Keyboard* GetKeyboardManager() const = 0;
       //@}
 
 
