@@ -97,6 +97,10 @@ namespace Lum {
 
         size_t GetSpaceHorizontal(OS::Display::Space space) const;
         size_t GetSpaceVertical(OS::Display::Space space) const;
+        
+        size_t GetIconWidth() const;
+        size_t GetIconHeight() const;
+        
         size_t GetMinimalButtonWidth() const;
         size_t GetFirstTabOffset() const;
         size_t GetLastTabOffset() const;
