@@ -22,6 +22,8 @@
 
 #include <Lum/Window.h>
 
+#include <Lum/PopupGroup.h>
+
 namespace Lum {
 
   class Popup;
@@ -33,6 +35,7 @@ namespace Lum {
   class LUMAPI Popup : public Window
   {
   private:
+    PopupGroup  *container;
     Lum::Object *main;
     Lum::Object *reference;
     OS::FillRef background;
