@@ -20,9 +20,6 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/Model/Action.h>
-
-#include <Lum/Popup.h>
 #include <Lum/PopupControl.h>
 
 namespace Lum {
@@ -30,25 +27,8 @@ namespace Lum {
   */
   class LUMAPI TimeSelect : public PopupControl
   {
-  private:
-    class TimeSelectPopup : public Popup
-    {
-    public:
-      Base::TimeFormat format;
-      TimeSelect       *select;
-      Model::ActionRef commit;
-
-    public:
-      TimeSelectPopup(TimeSelect *combo, Base::TimeFormat format);
-
-      void PreInit();
-
-      void Resync(Base::Model* model, const Base::ResyncMsg& msg);
-    };
-
   private:
     Base::TimeFormat format;
-    Popup*           popup;
 
   private:
     void OpenPopup();
@@ -61,7 +41,8 @@ namespace Lum {
 
     void Resync(Base::Model* model, const Base::ResyncMsg& msg);
 
-    static TimeSelect* Create(Base::Model* model=NULL, bool horizontalFlex=false, bool verticalFlex=false);
+    static TimeSelect* Create(Base::Model* model=NULL,
+                              bool horizontalFlex=false, bool verticalFlex=false);
   };
 }
 
