@@ -50,6 +50,8 @@
 #include <Lum/Base/L10N.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Manager/FileSystem.h>
+
 #include <Lum/OS/Display.h>
 
 namespace Lum {
@@ -63,8 +65,6 @@ namespace Lum {
     static std::wstring nativeSeparatorList=L"/";
 #endif
 
-    static std::wstring applicationDataDir;
-
     /**
       The constructor of the path
       @param nativePath An optional initial path in host native syntax.
@@ -541,97 +541,6 @@ namespace Lum {
       }
     }
 
-    /**
-      Reads the given environment variable and interprets it as a dirctory.
-      If the environment variable does not exists or is empty, L"" is returned.
-    */
-    std::wstring Path::GetDirFromEnvironment(const std::string& environment)
-    {
-      std::wstring result;
-      const char*  tmp;
-
-      tmp=getenv(environment.c_str());
-      if (tmp!=NULL) {
-        result=StringToWString(tmp);
-
-        if (!result.empty() && nativeSeparatorList.find(result[result.length()-1])==std::wstring::npos) {
-          result.append(1,nativeSeparator);
-        }
-      }
-
-      return result;
-    }
-
-    /**
-      Returns the home directory of the current user.
-    */
-    std::wstring Path::GetHome()
-    {
-      std::wstring home;
-
-#if defined(__WIN32__) || defined(WIN32)
-      home=GetDirFromEnvironment("USERPROFILE");
-#else
-      home=GetDirFromEnvironment("HOME");
-#endif
-      if (!home.empty()) {
-        return home;
-      }
-      else {
-        return GetCWD();
-      }
-    }
-
-    /**
-      Returns the default directory for temporary data.
-    */
-    std::wstring Path::GetTemporary()
-    {
-#if defined(__WIN32__) || defined(WIN32)
-      std::wstring temporary;
-
-      temporary=GetDirFromEnvironment("TEMP");
-      if (!temporary.empty()) {
-        return temporary;
-      }
-      else {
-        return GetCWD();
-      }
-#else
-      std::wstring temporary;
-
-      temporary=GetDirFromEnvironment("TMPDIR");
-      if (temporary.empty()) {
-        temporary=GetDirFromEnvironment("TMP");
-      }
-      if (temporary.empty()) {
-        temporary=L"/tmp";
-      }
-
-      return temporary;
-#endif
-    }
-
-    std::wstring Path::GetConfigDir()
-    {
-#if defined(__WIN32__) || defined(WIN32)
-      wchar_t path[MAX_PATH];
-
-      if (SUCCEEDED(SHGetFolderPathW(NULL,
-                    CSIDL_LOCAL_APPDATA|CSIDL_FLAG_CREATE,
-                    NULL,
-                    0,
-                    path))) {
-        return path;
-      }
-      else {
-        return GetHome();
-      }
-#else
-      return GetHome();
-#endif
-    }
-
     std::wstring Path::GetApplicationConfigFile()
     {
       std::wstring file(::Lum::OS::display->GetAppName());
@@ -649,95 +558,19 @@ namespace Lum {
 
     std::wstring Path::GetApplicationConfigPath()
     {
-      std::wstring dir(GetConfigDir());
+      std::wstring dir;
       std::wstring file(GetApplicationConfigFile());
       Path         path;
 
+      if (!Manager::FileSystem::Instance()->GetEntry(Manager::FileSystem::userConfigDir,dir)) {
+        Manager::FileSystem::Instance()->GetEntry(Manager::FileSystem::userDir,dir);
+      }
+
       path.SetNativeDirAndFile(dir,file);
 
       return path.GetPath();
     }
 
-    Path::PathDescription::PathDescription(const std::wstring& description, const std::wstring& path)
-     : description(description),path(path)
-    {
-      // No code
-    }
-
-    Path::PathDescription::~PathDescription()
-    {
-      // no code
-    }
-
-    void Path::GetStdPathes(std::vector<PathDescription>& list)
-    {
-      list.clear();
-
-#if defined(__WIN32__) || defined(WIN32)
-      size_t       size,pos;
-      wchar_t      *buffer;
-      std::wstring name;
-
-      size=GetLogicalDriveStringsW(0,NULL);
-
-      buffer=new wchar_t[size];
-      if (GetLogicalDriveStringsW(size,buffer)<=size) {
-        pos=0;
-        while (buffer[pos]!=L'\0') {
-          while (buffer[pos]!=L'\0') {
-            name.append(1,buffer[pos]);
-            pos++;
-          }
-
-          list.push_back(PathDescription(name,name));
-          name.erase();
-          pos++;
-        }
-      }
-
-      delete [] buffer;
-
-#else
-      ;
-      list.push_back(PathDescription(_l(L"BASE_PATH_ROOT",L"Filesystem"),L"/"));
-
-      Path path(GetHome());
-      path.AppendDir(L"Desktop");
-
-      if (path.Exists() && path.IsDir()) {
-        list.push_back(PathDescription(_l(L"BASE_PATH_DESKTOP",L"Desktop"),path.GetPath()));
-      }
-#endif
-      list.push_back(PathDescription(_l(L"BASE_PATH_HOME",L"Home"),GetHome()));
-      list.push_back(PathDescription(_l(L"BASE_PATH_TMP",L"Temporary"),GetTemporary()));
-
-      std::wstring envdir;
-
-      envdir=GetDirFromEnvironment("MYDOCSDIR");
-      if (!envdir.empty()) {
-        list.push_back(PathDescription(_l(L"BASE_PATH_DOCUMENTS",L"Documents"),envdir));
-      }
-    }
-
-      std::wstring Path::GetLibraryDataDir()
-      {
-#if defined(LIB_DATADIR)
-        return StringToWString(LIB_DATADIR);
-#else
-        L"";
-#endif
-      }
-
-      void Path::SetApplicationDataDir(const std::wstring& directory)
-      {
-        applicationDataDir=directory;
-      }
-
-      std::wstring Path::GetApplicationDataDir()
-      {
-        return applicationDataDir;
-      }
-
     Status Path::CreateDir(const std::wstring& nativePath)
     {
       Status status;
