@@ -455,16 +455,15 @@ namespace Lum {
     draw->focused=HasFocus();
   }
 
-  void Button::Draw(int x, int y, size_t w, size_t h)
+  void Button::Draw(OS::DrawInfo* draw,
+                    int x, int y, size_t w, size_t h)
   {
-    Control::Draw(x,y,w,h); /* We must call Draw of our superclass */
+    Control::Draw(draw,x,y,w,h); /* We must call Draw of our superclass */
 
     if (!OIntersect(x,y,w,h)) {
       return;
     }
 
-    OS::DrawInfo *draw=GetDrawInfo();
-
     /*
       Set the correct draw mode before calling the baseclass,
       since the baseclass draw the object frame.
@@ -485,7 +484,7 @@ namespace Lum {
 
     // Draw object
     if (ShowObject()) {
-      object->Draw(x,y,w,h);
+      object->Draw(draw,x,y,w,h);
     }
 
     // Draw optional image
