@@ -80,9 +80,10 @@ namespace Lum {
     draw->disabled=true;
   }
 
-  void DateView::Draw(int x, int y, size_t w, size_t h)
+  void DateView::Draw(OS::DrawInfo* draw,
+                      int x, int y, size_t w, size_t h)
   {
-    Object::Draw(x,y,w,h);
+    Object::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -90,7 +91,6 @@ namespace Lum {
 
     /* --- */
 
-    OS::DrawInfo   *draw=GetDrawInfo();
     std::wstring   buffer;
     OS::FontRef    font=OS::display->GetFont();
     OS::FontExtent extent;
