@@ -29,13 +29,9 @@ namespace Lum {
       assert(value!=NULL);
 
       Value  v;
-      String *string;
-
-      string=new String();
-      string->SetFlex(true,false);
 
       v.label=L"";
-      v.control=string;
+      v.control=String::Create(true,false);
       v.model=value;
       v.validator=validator;
 
