@@ -584,14 +584,22 @@ namespace Lum {
       // no code
     }
 
+    /**
+      (Re)Initialize the state
+     */
     void State::Init()
     {
       row=1;
+      memory.clear();
+      state.Reset();
       highMark=0;
-      memory.resize(1);
       cursor=text->GetOrCreateCursor(L"state",Cursor::cursorFix|Cursor::cursorHidden);
+      RememberState(1,state);
     }
 
+    /**
+       Store the given state for the given line, if line=highmark+1
+     */
     void State::RememberState(size_t line, const StateInfo& state)
     {
       if (line<highMark) {
@@ -600,9 +608,13 @@ namespace Lum {
 
       if (line>highMark) {
         assert(highMark+1==line);
-        if (line>memory.size()-1) {
-          // TODO: Find better resize algorithm
-          memory.resize(memory.size()*10);
+        if (line>=memory.size()) {
+          if (memory.size()==0) {
+            memory.resize(std::max(line,10000u));
+          }
+          else {
+            memory.resize(std::max(line,memory.size()*10));
+          }
         }
 
         memory[line]=state;
@@ -610,23 +622,35 @@ namespace Lum {
       }
     }
 
-    void State::MoveHighMark(size_t line)
-    {
-      if (line<highMark) {
-        highMark=line;
-      }
-    }
-
-    void State::MoveToLine(size_t line)
+    /**
+      Move the highmark back, thus droping state information for everything beyond
+      the high mark.
+     */
+    void State::ForgetStateBehindLine(size_t line)
     {
       if (line<1) {
         line=1;
       }
+      
+      if (line<highMark) {
+        cursor->Goto(1,line-1);
+        row=line;
+        state=memory[line];
+        highMark=line;
+      }
+    }
 
-      /*
-      if (line==row) {
-        return;
-      }*/
+    /**
+       Tell the state machine to move to the given line and calculate its state.
+       State will be either used by using the meory variable to get already
+       calculated state for a line or by calculating the new state by iterating
+       over the text and parsing it (from highmark up to line).
+     */
+    StateInfo State::MoveToLine(size_t line)
+    {
+      if (line<1) {
+        line=1;
+      }
 
       // See, if we can jump to a position close before the requested line
       if (line==1) {
@@ -634,13 +658,13 @@ namespace Lum {
         row=line;
         state.Reset(); // reinitialize
         RememberState(1,state);
-        return;
+        return state;
       }
       else if (line<=highMark) { // go back
         cursor->Goto(1,line-1);
         row=line;
         state=memory[line];
-        return;
+        return state;
       }
       else { // go forward
         std::wstring text;
@@ -673,6 +697,8 @@ namespace Lum {
           RememberState(row,state);
         }
       }
+      
+      return state;
     }
 
 
@@ -1137,7 +1163,6 @@ namespace Lum {
       this->syntax=syntax;
 
       state.Init();
-      state.MoveHighMark(1);
     }
 
     Cursor* Text::CreateCursor(const std::wstring& name, unsigned long flags)
@@ -1204,7 +1229,6 @@ namespace Lum {
       //t.syntax:=syntax;
 
       state.Init();
-      state.MoveHighMark(1);
 
       NotifyTextChanged();
       NotifyPropertyChanged();
@@ -1377,7 +1401,7 @@ namespace Lum {
 
       CountLines();
       ResetCursors();
-      state.MoveHighMark(1);
+      state.Init();
 
       file.open(Base::WStringToString(fileName).c_str(),std::ios::out|std::ios::binary);
       SetReadOnly(!file);
@@ -1699,6 +1723,7 @@ namespace Lum {
               (*c)->x=lastX+1;
             }
           }
+          
           (*c)->pos+=text.length();
           (*c)->y+=lines;
         }
@@ -1710,8 +1735,7 @@ namespace Lum {
         ++c;
       }
 
-      state.MoveToLine(oldY-1);
-      state.MoveHighMark(oldY-1);
+      state.ForgetStateBehindLine(oldY-1);
 
       SetChanged(true);
 
@@ -1763,8 +1787,7 @@ namespace Lum {
         return false;
       }
 
-      state.MoveToLine(markA->GetY()-1);
-      state.MoveHighMark(markA->GetY()-1);
+      state.ForgetStateBehindLine(markA->GetY()-1);
 
       if (markA->GetX()>markA->GetLineLength()+1) {
         // TODO: Do we really need to fill?
