@@ -24,12 +24,11 @@
 #include <Lum/String.h>
 
 namespace Lum {
-  static FileNameSelect::Prefs *prefs=new FileNameSelect::Prefs(L"FileNameSelect");
 
   FileNameSelect::FileNameSelect()
   : PopupControl(new String())
   {
-    SetPrefs(::Lum::prefs);
+    // no code
   }
 
   FileNameSelect::~FileNameSelect()
