@@ -38,6 +38,8 @@ namespace Lum {
       top->On(notify);
       visible->On(notify);
       total->On(notify);
+      
+      Model::On(notify);
     }
 
     void Adjustment::Off()
@@ -45,6 +47,8 @@ namespace Lum {
       top->Off();
       visible->Off();
       total->Off();
+      
+      Model::Off();
     }
 
     /**
@@ -184,10 +188,7 @@ namespace Lum {
       assert(top>=1);
       assert(top<=total->Get()-visible->Get()+1);
 
-      if (this->top->IsNull() || this->top->Get()!=top) {
-        this->top->Set(top);
-        Notify();
-      }
+      Set(top,GetVisible(),GetTotal());
     }
 
     /**
