@@ -93,13 +93,12 @@ namespace Lum {
     }
   }
 
-  void Multi::Draw(int x, int y, size_t w, size_t h)
+  void Multi::Draw(OS::DrawInfo* draw,
+                   int x, int y, size_t w, size_t h)
   {
     if (lastDrawn<list.size() &&
         ((!model.Valid() || model->IsNull()) ||
          (model.Valid() && !model->IsNull() && lastDrawn!=model->Get()))) {
-      Lum::OS::DrawInfo *draw;
-
       /*
         This is a little trick:
         We must hide the old object, but we do not want it to clean up the
@@ -107,7 +106,6 @@ namespace Lum {
         So we create a clipping region that completely covers the top be drawn
         area :-)
       */
-      draw=GetDrawInfo();
       draw->PushClipBegin(x,y,width,height);
       draw->SubClipRegion(x,y,width,height);
       draw->PushClipEnd();
@@ -117,7 +115,7 @@ namespace Lum {
       lastDrawn=std::numeric_limits<size_t>::max();
     }
 
-    Control::Draw(x,y,w,h); /* We must call Draw of our superclass */
+    Control::Draw(draw,x,y,w,h); /* We must call Draw of our superclass */
 
     if (!OIntersect(x,y,w,h)) {
       return;
