@@ -22,14 +22,18 @@
 #include <math.h>
 
 #if defined(CAIRO_HAS_WIN32_SURFACE)
-#include <Lum/OS/Win32/Display.h>
-#include <Lum/OS/Win32/Window.h>
-#elif defined(CAIRO_HAS_QUARTZ_SURFACE)
-#include <Lum/OS/Carbon/Display.h>
-#include <Lum/OS/Carbon/Window.h>
-#elif defined(CAIRO_HAS_XLIB_SURFACE)
-#include <Lum/OS/X11/Display.h>
-#include <Lum/OS/X11/Window.h>
+  #include <Lum/OS/Win32/Display.h>
+  #include <Lum/OS/Win32/Window.h>
+#endif
+
+#if defined(CAIRO_HAS_QUARTZ_SURFACE)
+  #include <Lum/OS/Carbon/Display.h>
+  #include <Lum/OS/Carbon/Window.h>
+#endif
+
+#if defined(CAIRO_HAS_XLIB_SURFACE)
+  #include <Lum/OS/X11/Display.h>
+  #include <Lum/OS/X11/Window.h>
 #endif
 
 #include <Lum/Base/String.h>
@@ -37,8 +41,6 @@
 #include <Lum/OS/Cairo/Bitmap.h>
 #include <Lum/OS/Cairo/Font.h>
 
-#include <iostream> 
-
 namespace Lum {
   namespace OS {
     namespace Cairo {
@@ -52,15 +54,7 @@ namespace Lum {
         colorPushCount(0),
         dashPushCount(0)
       {
-/*#if defined(CAIRO_HAS_WIN32_SURFACE)
-        surface=cairo_win32_surface_create(GetDC(dynamic_cast< ::Lum::OS::Win32::Window*>(window)->window));
-#elif defined(CAIRO_HAS_QUARTZ_SURFACE)
-        surface=cairo_quartz_surface_create(dynamic_cast< ::Lum::OS::Carbon::Window*>(window)->context,window->GetWidth(),window->GetHeight(),false);
-#endif
-        deleteSurface=true;
-        cairo=cairo_create(surface);
-
-        SetDefaults();*/
+        // no code
       }
 
       DrawInfo::DrawInfo(OS::Bitmap* bitmap)
@@ -69,12 +63,7 @@ namespace Lum {
         colorPushCount(0),
         dashPushCount(0)
       {
-/*        surface=dynamic_cast<Bitmap*>(bitmap)->surface;
-        deleteSurface=false;
-
-        cairo=cairo_create(surface);
-
-        SetDefaults();*/
+        // no code
       }
 
       /**
@@ -140,6 +129,7 @@ namespace Lum {
 
       void DrawInfo::ReinstallClip()
       {
+        // no code
       }
 
       void DrawInfo::PushFont(OS::Font *font, unsigned long style)
@@ -228,9 +218,9 @@ namespace Lum {
         cairo_save(cairo);
 
 #if defined(CAIRO_HAS_WIN32_SURFACE)
-        r=((double)GetRValue(color))/255;
-        g=((double)GetGValue(color))/255;
-        b=((double)GetBValue(color))/255;
+        r=GetRValue(color)/255.0;
+        g=GetGValue(color)/255.0;
+        b=GetBValue(color)/255.0;
 #elif defined(CAIRO_HAS_QUARTZ_SURFACE)
         r=(color/(256*256) % 256);
         g=(color/(256    ) % 256);
@@ -240,8 +230,35 @@ namespace Lum {
         g=g/255;
         b=b/255;
 #elif defined(CAIRO_HAS_XLIB_SURFACE)
-        GetRGBValue(color,r,g,b);
+        OS::X11::Display *display=dynamic_cast<OS::X11::Display*>(OS::display);
+
+        if (display->visual->bits_per_rgb==8 &&
+            display->visual->red_mask==0xFF0000 &&
+            display->visual->green_mask==0xFF00 &&
+            display->visual->blue_mask==0xFF) {
+          r=((color & 0XFF0000) >> 16)/255.0;
+          g=((color & 0X00FF00) >>  8)/255.0;
+          b=((color & 0X0000FF) >>  0)/255.0;
+        }
+        else {
+          XColor tmp;
+
+          tmp.pixel=color;
+          tmp.red=0;
+          tmp.green=0;
+          tmp.blue=0;
+          tmp.flags=0;
+
+          XQueryColor(display->display,
+                      display->colorMap,
+                      &tmp);
+
+          r=((double)tmp.red)/((double)std::numeric_limits<unsigned short>::max());
+          g=((double)tmp.green)/((double)std::numeric_limits<unsigned short>::max());
+          b=((double)tmp.blue)/((double)std::numeric_limits<unsigned short>::max());
+        }
 #endif
+
         cairo_set_source_rgb(cairo,r,g,b);
       }
 
@@ -287,7 +304,7 @@ namespace Lum {
 
       void DrawInfo::PushDash(const char* dashList, size_t len, DashMode /*mode*/)
       {
-	assert(dashList!=NULL && len>0);
+        assert(dashList!=NULL && len>0);
 
         dashPushCount++;
 
@@ -374,28 +391,12 @@ namespace Lum {
 
       void DrawInfo::DrawPointWithColor(int x, int y, OS::Color color)
       {
-        double r,g,b;
-#if defined(CAIRO_HAS_WIN32_SURFACE)
-        r=((double)GetRValue(color))/255;
-        g=((double)GetGValue(color))/255;
-        b=((double)GetBValue(color))/255;
-#elif defined(CAIRO_HAS_QUARTZ_SURFACE)
-        r=(color/(256*256) % 256);
-        g=(color/(256    ) % 256);
-        b=(color/(1      ) % 256);
-
-        r=r/255;
-        g=g/255;
-        b=b/255;
-#elif defined(CAIRO_HAS_XLIB_SURFACE)
-        GetRGBValue(color,r,g,b);
-#endif
-        cairo_save(cairo);
-        cairo_set_line_width(cairo,1);
-        cairo_set_source_rgb(cairo,r,g,b);
+        PushForeground(color);
+        PushPen(1,penNormal);
         cairo_arc(cairo,x+0.5,y+0.5,1.0,0,360*(M_PI/180.0));
         cairo_fill(cairo);
-        cairo_restore(cairo);
+        PopPen();
+        PopForeground();
       }
 
       void DrawInfo::DrawLine(int x1, int y1, int x2, int y2)
@@ -527,17 +528,27 @@ namespace Lum {
       {
         dc=GetDC(dynamic_cast<OS::Win32::Window*>(window)->window);
 
-        
         surface=cairo_win32_surface_create(dc);
 
         deleteSurface=true;
         cairo=cairo_create(surface);
 
-        std::cout << "DrawInfo/Window :" << dc << " " << surface << " " << cairo << std::endl;
-        
         SetDefaults();
       }
 
+      Win32DrawInfo::Win32DrawInfo(OS::Window* window, HDC dc)
+      : DrawInfo(bitmap)
+      {
+        this->dc=dc;
+
+        surface=cairo_win32_surface_create(dc);
+
+        deleteSurface=true;
+        cairo=cairo_create(surface);
+
+        SetDefaults();
+     }
+
       Win32DrawInfo::Win32DrawInfo(OS::Bitmap* bitmap)
       : DrawInfo(bitmap)
       {
@@ -548,8 +559,6 @@ namespace Lum {
 
         cairo=cairo_create(surface);
 
-        std::cout << "DrawInfo/Bitmap :" << dc << " " << surface << " " << cairo << std::endl;
-        
         SetDefaults();
       }
 
@@ -568,9 +577,8 @@ namespace Lum {
       {
         assert(false);
       }
-
 #endif
-      
+
 #if defined(CAIRO_HAS_XLIB_SURFACE)
       X11DrawInfo::X11DrawInfo(OS::Window* window)
       : DrawInfo(window)
@@ -614,32 +622,11 @@ namespace Lum {
         }
       }
 
-      void X11DrawInfo::GetRGBValue(Color color, double &r, double &g, double &b)
-      {
-        XColor tmp;
-
-        tmp.pixel=color;
-        tmp.red=0;
-        tmp.green=0;
-        tmp.blue=0;
-        tmp.flags=0;
-
-        XQueryColor(dynamic_cast<OS::X11::Display*>(OS::display)->display,
-                    dynamic_cast<OS::X11::Display*>(OS::display)->colorMap,
-                    &tmp);
-
-        r=((double)tmp.red)/((double)std::numeric_limits<unsigned short>::max());
-        g=((double)tmp.green)/((double)std::numeric_limits<unsigned short>::max());
-        b=((double)tmp.blue)/((double)std::numeric_limits<unsigned short>::max());
-      }
-
       void X11DrawInfo::SetNewSize(size_t width, size_t height)
       {
         cairo_xlib_surface_set_size(surface,width,height);
       }
-
 #endif
-
     }
   }
 }
