@@ -208,7 +208,7 @@ namespace Lum {
           int bg=GetBackground(x,y);
           int style;
 
-          switch (fontStack.top().style & (Font::maxStyleNum-1)) {
+          switch (fontStack.top().style & (Font::bold|Font::italic|Font::underlined|Font::slanted)) {
           case Font::normal:
           case Font::italic:
           case Font::slanted:
