@@ -63,6 +63,16 @@ namespace Lum {
       draw->FillRectangle(x,y,w,h);
       draw->PopForeground();
     }
+
+    /**
+      Does draw anything.
+    */
+    void EmptyFill::Draw(OS::DrawInfo* /*draw*/,
+                         int /*xOff*/, int /*yOff*/, size_t /*width*/, size_t /*height */,
+                         int /*x*/, int /*y*/, size_t /*w*/, size_t /*h*/)
+    {
+      // no code
+    }
   }
 }
 
