@@ -39,7 +39,7 @@ namespace Lum {
     namespace Hildon {
 
 #if HILDON_CHECK_VERSION(2,1,0)
-      class CustomMenuHandlerPopup : public OS::Behaviour::CustomMenuHandler
+      class CustomMenuHandlerPopup : public Manager::Behaviour::CustomMenuHandler
       {
       private:
         static const size_t columns = 2;
@@ -89,7 +89,7 @@ namespace Lum {
                   booleans.insert(b.GetBoolean());
                   ObservePrior(b.GetBoolean());
 
-                  Lum::Object *object=OS::display->GetBehaviour()->GetBooleanControl(b,true,false);
+                  Lum::Object *object=Manager::Behaviour::Instance()->GetBooleanControl(b,true,false);
 
                   array->Add(object);
                 }
@@ -233,7 +233,7 @@ namespace Lum {
 
       public:
         CustomMenuHandlerPopup(OS::Window* window)
-        : OS::Behaviour::CustomMenuHandler(window),
+        : Manager::Behaviour::CustomMenuHandler(window),
           menu(NULL),
           popup(NULL)
         {
@@ -332,7 +332,7 @@ namespace Lum {
 
 #endif
 
-      OS::Behaviour::CustomMenuHandler* Behaviour::GetCustomMenuHandler(OS::Window* window) const
+      Manager::Behaviour::CustomMenuHandler* Behaviour::GetCustomMenuHandler(OS::Window* window) const
       {
         return new CustomMenuHandlerPopup(window);
       }
@@ -496,6 +496,11 @@ namespace Lum {
 #endif
       }
 
+      Behaviour::TableActionMode Behaviour::GetTableDefaultActionMode() const
+      {
+        return TableActionOnSelection;
+      }
+
       void Behaviour::ApplyMultiViewDlg(Dialog* dialog,
                                         const Def::MultiView& multiView) const
       {
@@ -547,14 +552,38 @@ namespace Lum {
 #endif
       }
 
-      Lum::Object* Behaviour::GetOneOfManyControl(Def::OneOfMany& def) const
+      Lum::Object* Behaviour::GetOneOfNControl(const Def::OneOfN& def) const
+      {
+#if HILDON_CHECK_VERSION(2,1,0)
+        TableIndexValueButton *control;
+        Model::StringTableRef choices(new Model::StringTable());
+
+        for (std::list<Def::OneOfN::Choice>::const_iterator iter=def.GetChoices().begin();
+            iter!=def.GetChoices().end();
+            ++iter) {
+          choices->Append(iter->GetDesc().GetLabel());
+        }
+
+        control=TableIndexValueButton::Create(def.GetDesc().GetLabel(),
+                                              def.GetValue(),
+                                              choices,
+                                              new StringTablePainter());
+
+        return control;
+#else
+        return DefaultBehaviour::GetOneOfNControl(def);
+#endif
+      }
+
+      Lum::Object* Behaviour::GetOneOfManyControl(const Def::OneOfMany& def) const
       {
 #if HILDON_CHECK_VERSION(2,1,0)
         TableIndexValueButton *control;
 
-        control=new TableIndexValueButton(def.GetChoices());
-        control->SetModel(def.GetValue());
-        control->SetLabel(def.GetDesc().GetLabel());
+        control=TableIndexValueButton::Create(def.GetDesc().GetLabel(),
+                                              def.GetValue(),
+                                              def.GetChoices(),
+                                              def.GetTableCellPainter());
 
         return control;
 #else
@@ -562,7 +591,7 @@ namespace Lum {
 #endif
       }
 
-      Lum::Object* Behaviour::GetBooleanControl(Def::Boolean& def) const
+      Lum::Object* Behaviour::GetBooleanControl(const Def::Boolean& def) const
       {
 #if HILDON_CHECK_VERSION(2,1,0)
         BooleanButton *control;
