@@ -17,7 +17,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 */
 
-#include <Lum/OS/Hildon/DisplayManager.h>
+#include <Lum/OS/Hildon/Display.h>
 
 #include <Lum/OS/X11/Display.h>
 #include <iostream>
@@ -27,7 +27,7 @@ namespace Lum {
 
       void OssoDisplayEventCallback(osso_display_state_t state, gpointer data)
       {
-        DisplayManager  *manager=static_cast<DisplayManager*>(data);
+        Display  *manager=static_cast<Display*>(data);
 
         assert(manager!=NULL);
 
@@ -35,20 +35,20 @@ namespace Lum {
         case OSSO_DISPLAY_ON:
         case OSSO_DISPLAY_DIMMED:
           std::cout << "Display event: ON (" << state << ")" << std::endl;
-          manager->SetDisplayState(DisplayManager::DisplayStateOn);
+          manager->SetDisplayState(Display::DisplayStateOn);
           break;
         case OSSO_DISPLAY_OFF:
           std::cout << "Display event: OFF (" << state << ")" << std::endl;
-          manager->SetDisplayState(DisplayManager::DisplayStateOff);
+          manager->SetDisplayState(Display::DisplayStateOff);
           break;
         default:
           std::cout << "Display event: unknown (" << state << ")" << std::endl;
-          manager->SetDisplayState(DisplayManager::DisplayStateUnknown);
+          manager->SetDisplayState(Display::DisplayStateUnknown);
           break;
         }
       }
 
-      DisplayManager::DisplayManager()
+      Display::Display()
        : displayState(DisplayStateUnknown),
          displayStateChangeAction(new Model::Action()),
          timerAction(new Model::Action())
@@ -66,9 +66,11 @@ namespace Lum {
         if (result!=OSSO_OK) {
           std::cout << "Installing osso display event callback failed: " << result << std::endl;
         }
+
+        Observe(timerAction);
       }
 
-      void DisplayManager::SetDisplayState(DisplayState displayState)
+      void Display::SetDisplayState(DisplayState displayState)
       {
         if (this->displayState!=displayState) {
           this->displayState=displayState;
@@ -76,17 +78,17 @@ namespace Lum {
         }
       }
 
-      DisplayManager::DisplayState DisplayManager::GetDisplayState() const
+      Display::DisplayState Display::GetDisplayState() const
       {
         return displayState;
       };
 
-      Model::Action* DisplayManager::GetDisplayStateChangeAction() const
+      Model::Action* Display::GetDisplayStateChangeAction() const
       {
         return displayStateChangeAction;
       }
 
-      bool DisplayManager::AllowScreenBlanking(bool blankable)
+      bool Display::AllowScreenBlanking(bool blankable)
       {
         X11::Display *display=dynamic_cast<X11::Display*>(OS::display);
 
@@ -109,7 +111,7 @@ namespace Lum {
         }
       }
 
-      void DisplayManager::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
+      void Display::Resync(Lum::Base::Model* model, const Lum::Base::ResyncMsg& msg)
       {
         if (model==timerAction && timerAction->IsFinished()) {
           X11::Display *display=dynamic_cast<X11::Display*>(OS::display);
