@@ -326,7 +326,7 @@ namespace Lum {
       {
         assert(status==statusShown);
 
-        XCopyArea(display->display,dynamic_cast<Bitmap*>(bitmap)->pixmap,window,gc,0,0,width,height,0,0);
+        //XCopyArea(display->display,dynamic_cast<Bitmap*>(bitmap)->pixmap,window,gc,0,0,width,height,0,0);
       }
 
       void Tray::SetTitle(const std::wstring& title)
