@@ -94,9 +94,10 @@ namespace Lum {
     Object::CalcSize();
   }
 
-  void HScale::Draw(int x, int y, size_t w, size_t h)
+  void HScale::Draw(OS::DrawInfo* draw,
+                    int x, int y, size_t w, size_t h)
   {
-    Object::Draw(x,y,w,h);
+    Object::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -104,8 +105,7 @@ namespace Lum {
 
     /* --- */
 
-    int          interval,exp,max,pos,mark,off,width,height,intv;
-    OS::DrawInfo *draw=GetDrawInfo();
+    int interval,exp,max,pos,mark,off,width,height,intv;
 
     interval=to-from;
 
@@ -168,18 +168,16 @@ namespace Lum {
     Object::CalcSize();
   }
 
-  void VScale::Draw(int x, int y, size_t w, size_t h)
+  void VScale::Draw(OS::DrawInfo* draw,
+                    int x, int y, size_t w, size_t h)
   {
-    int          interval,exp,max,pos,mark,off,width,height,intv;
-    OS::DrawInfo *draw;
+    Object::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
     }
 
-    Object::Draw(x,y,w,h);
-
-    draw=GetDrawInfo();
+    int interval,exp,max,pos,mark,off,width,height,intv;
 
     interval=to-from;
 
