@@ -110,40 +110,42 @@ namespace Lum {
 
   void Scroller::CalcSize()
   {
-    if (vert) {
-      panel=new VPanel();
-      panel->SetFlex(false,true);
-    }
-    else {
-      panel=new HPanel();
-      panel->SetFlex(true,false);
-    }
-    panel->SetParent(this);
+    if (panel==NULL) {
+      if (vert) {
+        panel=new VPanel();
+        panel->SetFlex(false,true);
+      }
+      else {
+        panel=new HPanel();
+        panel->SetFlex(true,false);
+      }
+      panel->SetParent(this);
 
-    switch (OS::display->GetTheme()->GetScrollKnobMode()) {
+      switch (OS::display->GetTheme()->GetScrollKnobMode()) {
       case OS::Theme::scrollKnobModeSingle:
-      panel->Add(CreateButton(vert,true));
-      break;
+        panel->Add(CreateButton(vert,true));
+        break;
       case OS::Theme::scrollKnobModeDouble:
-      panel->Add(CreateButton(vert,true));
-      panel->Add(CreateButton(vert,false));
-      break;
+        panel->Add(CreateButton(vert,true));
+        panel->Add(CreateButton(vert,false));
+        break;
       case OS::Theme::scrollKnobModeNone:
-      break;
-    }
+        break;
+      }
 
-    panel->Add(knob);
+      panel->Add(knob);
 
-    switch (OS::display->GetTheme()->GetScrollKnobMode()) {
+      switch (OS::display->GetTheme()->GetScrollKnobMode()) {
       case OS::Theme::scrollKnobModeSingle:
-      panel->Add(CreateButton(vert,false));
-      break;
+        panel->Add(CreateButton(vert,false));
+        break;
       case OS::Theme::scrollKnobModeDouble:
-      panel->Add(CreateButton(vert,true));
-      panel->Add(CreateButton(vert,false));
-      break;
+        panel->Add(CreateButton(vert,true));
+        panel->Add(CreateButton(vert,false));
+        break;
       case OS::Theme::scrollKnobModeNone:
-      break;
+        break;
+      }
     }
 
     panel->CalcSize();
@@ -164,9 +166,10 @@ namespace Lum {
     Control::Layout();
   }
 
-  void Scroller::Draw(int x, int y, size_t w, size_t h)
+  void Scroller::Draw(OS::DrawInfo* draw,
+                      int x, int y, size_t w, size_t h)
   {
-    Control::Draw(x,y,w,h);
+    Control::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -174,7 +177,7 @@ namespace Lum {
 
     /* --- */
 
-    panel->Draw(x,y,w,h);
+    panel->Draw(draw,x,y,w,h);
   }
 
   void Scroller::Hide()
