@@ -160,11 +160,10 @@ namespace Lum {
     draw->activated=IsMouseActive();
   }
 
-  void State::Draw(int x, int y, size_t w, size_t h)
+  void State::Draw(OS::DrawInfo* draw,
+                   int x, int y, size_t w, size_t h)
   {
-    OS::DrawInfo *draw=GetDrawInfo();
-
-    Control::Draw(x,y,w,h);
+    Control::Draw(draw,x,y,w,h);
 
     if (!OIntersect(x,y,w,h)) {
       return;
@@ -193,7 +192,7 @@ namespace Lum {
     draw->focused=HasFocus();
     draw->activated=IsMouseActive();
 
-    DrawContent(x,y,w,h);
+    DrawContent(draw,x,y,w,h);
 
     draw->selected=false;
     draw->activated=false;
@@ -227,11 +226,12 @@ namespace Lum {
     State::CalcSize();
   }
 
-  void ImageState::DrawContent(int x, int y, size_t w, size_t h)
+  void ImageState::DrawContent(OS::DrawInfo* draw,
+                               int x, int y, size_t w, size_t h)
   {
     assert(image.Valid());
 
-    image->Draw(GetDrawInfo(),
+    image->Draw(draw,
                 this->x,this->y);
   }
 
