@@ -95,10 +95,11 @@ namespace Lum {
     State::Layout();
   }
 
-  void Toggle::DrawContent(int x, int y, size_t w, size_t h)
+  void Toggle::DrawContent(OS::DrawInfo* draw,
+                           int x, int y, size_t w, size_t h)
   {
     if (label!=NULL) {
-      label->Draw(x,y,w,h);
+      label->Draw(draw,x,y,w,h);
     }
   }
 
